import re
import os
from ctypes import *
from ctypes.util import find_library

libc = cdll.LoadLibrary(find_library("c"))
sysctlbyname = libc.sysctlbyname

def posix_sysctlbyname(name):
    _len = c_uint(0)
    result = sysctlbyname(name,None , byref(_len), None, 0)
    _mem = create_string_buffer(_len.value)
    result = sysctlbyname(name, _mem, byref(_len), None, 0)
    if result != 0:
        raise Exception('sysctlbyname returned with error %s' % result)
    return _mem.value

def usb_vid_pid(name):
    dev = bytes(name[8:],'ascii')
    for i in range(len(os.listdir('/dev/usb'))):
        try:
            found_dev = posix_sysctlbyname(b'dev.umodem.'+bytes(str(i),'ascii')+b'.ttyname')
            if dev == found_dev:
                result = (posix_sysctlbyname(b'dev.umodem.'+bytes(str(i),'ascii')+b'.%pnpinfo')).decode('ascii')
                items=result.split(' ')
                vendor=int(items[0].split('=')[1],0)
                product=int(items[1].split('=')[1],0)
                return([vendor,product])
        except:
            pass
    return [-1,-1]



--- setup.py.orig	2025-11-07 16:49:52 UTC
+++ setup.py
@@ -57,6 +57,7 @@ if prefer_system_zopfli:
         "sources": [
             "src/zopflimodule.c",
         ],
+        "include_dirs": ["%%LOCALBASE%%/include/zopfli", "%%LOCALBASE%%/include/zopflipng"],
         "libraries": ["zopfli", "zopflipng"],
         "define_macros": system_define_macros,
     }



#!/usr/bin/env python3
#
# This script removes the given package entries in the bundled_packages JSON files. This is used by the PluginInstall
# CMake module.
#

import argparse
import collections
import json
import os
import sys


## Finds all JSON files in the given directory recursively and returns a list of those files in absolute paths.
#
#  \param work_dir The directory to look for JSON files recursively.
#  \return A list of JSON files in absolute paths that are found in the given directory.
def find_json_files(work_dir: str) -> list:
    json_file_list = []
    for root, dir_names, file_names in os.walk(work_dir):
        for file_name in file_names:
            abs_path = os.path.abspath(os.path.join(root, file_name))
            json_file_list.append(abs_path)
    return json_file_list


## Removes the given entries from the given JSON file. The file will modified in-place.
#
#  \param file_path The JSON file to modify.
#  \param entries A list of strings as entries to remove.
#  \return None
def remove_entries_from_json_file(file_path: str, entries: list) -> None:
    try:
        with open(file_path, "r", encoding = "utf-8") as f:
            package_dict = json.load(f, object_hook = collections.OrderedDict)
    except Exception as e:
        msg = "Failed to load '{file_path}' as a JSON file. This file will be ignored Exception: {e}"\
            .format(file_path = file_path, e = e)
        sys.stderr.write(msg + os.linesep)
        return

    for entry in entries:
        if entry in package_dict:
            del package_dict[entry]
            print("[INFO] Remove entry [{entry}] from [{file_path}]".format(file_path = file_path, entry = entry))

    try:
        with open(file_path, "w", encoding = "utf-8", newline = "\n") as f:
            json.dump(package_dict, f, indent = 4)
    except Exception as e:
        msg = "Failed to write '{file_path}' as a JSON file. Exception: {e}".format(file_path = file_path, e = e)
        raise IOError(msg)


def main() -> None:
    parser = argparse.ArgumentParser("mod_bundled_packages_json")
    parser.add_argument("-d", "--dir", dest = "work_dir",
                        help = "The directory to look for bundled packages JSON files, recursively.")
    parser.add_argument("entries", metavar = "ENTRIES", type = str, nargs = "+")

    args = parser.parse_args()

    json_file_list = find_json_files(args.work_dir)
    for json_file_path in json_file_list:
        remove_entries_from_json_file(json_file_path, args.entries)


if __name__ == "__main__":
    main()



--- buildscripts/scons.py.orig	2024-07-23 11:11:41 UTC
+++ buildscripts/scons.py
@@ -18,15 +18,6 @@ sys.path = [SCONS_DIR, SITE_TOOLS_DIR] + sys.path
 
 sys.path = [SCONS_DIR, SITE_TOOLS_DIR] + sys.path
 
-# pylint: disable=C0413
-from mongo.pip_requirements import verify_requirements, MissingRequirements
-
-try:
-    verify_requirements()
-except MissingRequirements as ex:
-    print(ex)
-    sys.exit(1)
-
 try:
     import SCons.Script
 except ImportError as import_err:



--- setup.py.orig	2021-10-13 15:57:11 UTC
+++ setup.py
@@ -32,7 +32,7 @@ setup(name='deeptoolsintervals',
       author_email="ryan@ie-freiburg.mpg.de",
       url="https://github.com/deeptools/deeptools_intervals",
       keywords=["bioinformatics", "GTF"],
-      classifier=["Development Status :: 5 - Production/Stable",
+      classifiers=["Development Status :: 5 - Production/Stable",
                   "Environment :: Console",
                   "License :: OSI Approved :: MIT License",
                   "Intended Audience :: Developers",



--- beetsplug/ipfs.py.orig	2025-01-13 12:04:44 UTC
+++ beetsplug/ipfs.py
@@ -134,9 +134,9 @@ class IPFSPlugin(BeetsPlugin):
         self._log.info("Adding {0} to ipfs", album_dir)
 
         if self.config["nocopy"]:
-            cmd = "ipfs add --nocopy -q -r".split()
+            cmd = "kubo-go add --nocopy -q -r".split()
         else:
-            cmd = "ipfs add -q -r".split()
+            cmd = "kubo-go add -q -r".split()
         cmd.append(album_dir)
         try:
             output = util.command_output(cmd).stdout.split()
@@ -178,7 +178,7 @@ class IPFSPlugin(BeetsPlugin):
 
     def ipfs_get_from_hash(self, lib, _hash):
         try:
-            cmd = "ipfs get".split()
+            cmd = "kubo-go get".split()
             cmd.append(_hash)
             util.command_output(cmd)
         except (OSError, subprocess.CalledProcessError) as err:
@@ -202,9 +202,9 @@ class IPFSPlugin(BeetsPlugin):
             self.ipfs_added_albums(lib, tmp.name)
             try:
                 if self.config["nocopy"]:
-                    cmd = "ipfs add --nocopy -q ".split()
+                    cmd = "kubo-go add --nocopy -q ".split()
                 else:
-                    cmd = "ipfs add -q ".split()
+                    cmd = "kubo-go add -q ".split()
                 cmd.append(tmp.name)
                 output = util.command_output(cmd).stdout
             except (OSError, subprocess.CalledProcessError) as err:
@@ -230,7 +230,7 @@ class IPFSPlugin(BeetsPlugin):
                 return False
         path = os.path.join(remote_libs, lib_name.encode() + b".db")
         if not os.path.exists(path):
-            cmd = f"ipfs get {_hash} -o".split()
+            cmd = f"kubo-go get {_hash} -o".split()
             cmd.append(path)
             try:
                 util.command_output(cmd)



--- site_scons/RHVoicePackaging/windows.py.orig	2019-12-31 08:13:15 UTC
+++ site_scons/RHVoicePackaging/windows.py
@@ -19,7 +19,7 @@ import codecs
 import os.path
 from collections import OrderedDict
 import uuid
-from lxml import etree
+#from lxml import etree
 from .common import *
 
 uuid_namespace=uuid.UUID(hex="de5ba08b-8b9f-46e3-b0ee-d6bbac37017c")
